aboutsummaryrefslogtreecommitdiff
path: root/gdb/regcache.c
diff options
context:
space:
mode:
authorAndrew Cagney <cagney@redhat.com>2003-10-02 20:28:31 +0000
committerAndrew Cagney <cagney@redhat.com>2003-10-02 20:28:31 +0000
commit12c266ea569cae11221236dd5844f4136465ec88 (patch)
tree85b3c4f2e37d517888ffcadaf37ad986c1ad7c2c /gdb/regcache.c
parente3b1168e9d33402a660dcc28eee716c65405bc06 (diff)
downloadfsf-binutils-gdb-12c266ea569cae11221236dd5844f4136465ec88.zip
fsf-binutils-gdb-12c266ea569cae11221236dd5844f4136465ec88.tar.gz
fsf-binutils-gdb-12c266ea569cae11221236dd5844f4136465ec88.tar.bz2
2003-10-02 Andrew Cagney <cagney@redhat.com>
* gdbarch.sh (DEPRECATED_REGISTER_RAW_SIZE): Rename REGISTER_RAW_SIZE. * gdbarch.h, gdbarch.c: Re-generate. * aix-thread.c, alpha-tdep.h, arm-tdep.c, core-sol2.c: Update. * cris-tdep.c, dve3900-rom.c, findvar.c, frame.c: Update. * hppa-tdep.c, hppab-nat.c, hppah-nat.c, hppam3-nat.c: Update. * hpux-thread.c, i386gnu-nat.c, ia64-aix-nat.c: Update. * ia64-linux-nat.c, ia64-tdep.c, infcmd.c, infptrace.c: Update. * infrun.c, irix5-nat.c, lynx-nat.c, mips-linux-tdep.c: Update. * mips-nat.c, mips-tdep.c, mipsv4-nat.c, mn10300-tdep.c: Update. * monitor.c, ns32k-tdep.c, ppc-linux-nat.c, regcache.c: Update. * remote-e7000.c, remote-mips.c, remote-sim.c: Update. * remote-vxmips.c, remote-vxsparc.c, remote.c: Update. * rom68k-rom.c, rs6000-nat.c, rs6000-tdep.c, s390-tdep.c: Update. * sh64-tdep.c, sparc-nat.c, sparc-tdep.c, stack.c: Update. * target.c, tracepoint.c, v850-tdep.c, v850ice.c, valops.c: Update. * vax-tdep.c, vax-tdep.h, x86-64-tdep.c, xstormy16-tdep.c: Update. * config/m68k/tm-delta68.h, config/m68k/tm-vx68.h: Update. * config/sparc/tm-sparc.h, config/sparc/tm-sparclynx.h: Update. 2003-10-02 Andrew Cagney <cagney@redhat.com> * gdbint.texinfo (Target Architecture Definition): Rename REGISTER_RAW_SIZE to DEPRECATED_REGISTER_RAW_SIZE. * gdb.texinfo (Packets, Stop Reply Packets): Ditto. * gdbint.texinfo (Target Architecture Definition): Rename 2003-10-02 Andrew Cagney <cagney@redhat.com> * mi-main.c: Rename REGISTER_RAW_SIZE to DEPRECATED_REGISTER_RAW_SIZE.
Diffstat (limited to 'gdb/regcache.c')
-rw-r--r--gdb/regcache.c33
1 files changed, 17 insertions, 16 deletions
diff --git a/gdb/regcache.c b/gdb/regcache.c
index a36cd1e..ccb4e80 100644
--- a/gdb/regcache.c
+++ b/gdb/regcache.c
@@ -112,8 +112,8 @@ init_legacy_regcache_descr (struct gdbarch *gdbarch,
to overlap. Ulgh! New targets use gdbarch's register
read/write and entirely avoid this uglyness. */
descr->register_offset[i] = DEPRECATED_REGISTER_BYTE (i);
- descr->sizeof_register[i] = REGISTER_RAW_SIZE (i);
- gdb_assert (MAX_REGISTER_SIZE >= REGISTER_RAW_SIZE (i));
+ descr->sizeof_register[i] = DEPRECATED_REGISTER_RAW_SIZE (i);
+ gdb_assert (MAX_REGISTER_SIZE >= DEPRECATED_REGISTER_RAW_SIZE (i));
gdb_assert (MAX_REGISTER_SIZE >= DEPRECATED_REGISTER_VIRTUAL_SIZE (i));
}
@@ -187,7 +187,7 @@ init_regcache_descr (struct gdbarch *gdbarch)
/* If an old style architecture, fill in the remainder of the
register cache descriptor using the register macros. */
/* NOTE: cagney/2003-06-29: If either of DEPRECATED_REGISTER_BYTE or
- REGISTER_RAW_SIZE are still present, things are most likely
+ DEPRECATED_REGISTER_RAW_SIZE are still present, things are most likely
totally screwed. Ex: an architecture with raw register sizes
smaller than what DEPRECATED_REGISTER_BYTE indicates; non
monotonic DEPRECATED_REGISTER_BYTE values. For GDB 6 check for
@@ -196,7 +196,8 @@ init_regcache_descr (struct gdbarch *gdbarch)
if ((!gdbarch_pseudo_register_read_p (gdbarch)
&& !gdbarch_pseudo_register_write_p (gdbarch)
&& !gdbarch_register_type_p (gdbarch))
- || DEPRECATED_REGISTER_BYTE_P () || REGISTER_RAW_SIZE_P ())
+ || DEPRECATED_REGISTER_BYTE_P ()
+ || DEPRECATED_REGISTER_RAW_SIZE_P ())
{
descr->legacy_p = 1;
init_legacy_regcache_descr (gdbarch, descr);
@@ -242,7 +243,7 @@ init_regcache_descr (struct gdbarch *gdbarch)
if (DEPRECATED_REGISTER_BYTE_P ())
gdb_assert (descr->register_offset[i] == DEPRECATED_REGISTER_BYTE (i));
#if 0
- gdb_assert (descr->sizeof_register[i] == REGISTER_RAW_SIZE (i));
+ gdb_assert (descr->sizeof_register[i] == DEPRECATED_REGISTER_RAW_SIZE (i));
gdb_assert (descr->sizeof_register[i] == DEPRECATED_REGISTER_VIRTUAL_SIZE (i));
#endif
}
@@ -278,9 +279,9 @@ register_size (struct gdbarch *gdbarch, int regnum)
int size;
gdb_assert (regnum >= 0 && regnum < (NUM_REGS + NUM_PSEUDO_REGS));
size = descr->sizeof_register[regnum];
/* NB: The deprecated REGISTER_RAW_SIZE, if not provided, defaults
to the size of the register's type. */
- gdb_assert (size == REGISTER_RAW_SIZE (regnum)); /* OK */
+ gdb_assert (size == DEPRECATED_REGISTER_RAW_SIZE (regnum)); /* OK */
/* NB: Don't check the register's virtual size. It, in say the case
of the MIPS, may not match the raw size! */
return size;
@@ -661,7 +662,7 @@ deprecated_read_register_bytes (int in_start, char *in_buf, int in_len)
int byte;
reg_start = DEPRECATED_REGISTER_BYTE (regnum);
- reg_len = REGISTER_RAW_SIZE (regnum);
+ reg_len = DEPRECATED_REGISTER_RAW_SIZE (regnum);
reg_end = reg_start + reg_len;
if (reg_end <= in_start || in_end <= reg_start)
@@ -726,7 +727,7 @@ legacy_read_register_gen (int regnum, char *myaddr)
target_fetch_registers (regnum);
memcpy (myaddr, register_buffer (current_regcache, regnum),
- REGISTER_RAW_SIZE (regnum));
+ DEPRECATED_REGISTER_RAW_SIZE (regnum));
}
void
@@ -913,7 +914,7 @@ legacy_write_register_gen (int regnum, const void *myaddr)
registers_ptid = inferior_ptid;
}
- size = REGISTER_RAW_SIZE (regnum);
+ size = DEPRECATED_REGISTER_RAW_SIZE (regnum);
if (real_register (regnum))
{
@@ -1023,7 +1024,7 @@ deprecated_write_register_bytes (int myregstart, char *myaddr, int inlen)
int regstart, regend;
regstart = DEPRECATED_REGISTER_BYTE (regnum);
- regend = regstart + REGISTER_RAW_SIZE (regnum);
+ regend = regstart + DEPRECATED_REGISTER_RAW_SIZE (regnum);
/* Is this register completely outside the range the user is writing? */
if (myregend <= regstart || regend <= myregstart)
@@ -1152,9 +1153,9 @@ register_offset_hack (struct gdbarch *gdbarch, int regnum)
ULONGEST
read_register (int regnum)
{
- char *buf = alloca (REGISTER_RAW_SIZE (regnum));
+ char *buf = alloca (DEPRECATED_REGISTER_RAW_SIZE (regnum));
deprecated_read_register_gen (regnum, buf);
- return (extract_unsigned_integer (buf, REGISTER_RAW_SIZE (regnum)));
+ return (extract_unsigned_integer (buf, DEPRECATED_REGISTER_RAW_SIZE (regnum)));
}
ULONGEST
@@ -1185,7 +1186,7 @@ write_register (int regnum, LONGEST val)
{
void *buf;
int size;
- size = REGISTER_RAW_SIZE (regnum);
+ size = DEPRECATED_REGISTER_RAW_SIZE (regnum);
buf = alloca (size);
store_signed_integer (buf, size, (LONGEST) val);
deprecated_write_register_gen (regnum, buf);
@@ -1551,7 +1552,7 @@ regcache_dump (struct regcache *regcache, struct ui_file *file,
fprintf_unfiltered (file, " %5ld",
regcache->descr->sizeof_register[regnum]);
if ((regcache->descr->sizeof_register[regnum]
- != REGISTER_RAW_SIZE (regnum))
+ != DEPRECATED_REGISTER_RAW_SIZE (regnum))
|| (regcache->descr->sizeof_register[regnum]
!= DEPRECATED_REGISTER_VIRTUAL_SIZE (regnum))
|| (regcache->descr->sizeof_register[regnum]
@@ -1609,7 +1610,7 @@ regcache_dump (struct regcache *regcache, struct ui_file *file,
regcache_raw_read (regcache, regnum, buf);
fprintf_unfiltered (file, "0x");
dump_endian_bytes (file, TARGET_BYTE_ORDER, buf,
- REGISTER_RAW_SIZE (regnum));
+ DEPRECATED_REGISTER_RAW_SIZE (regnum));
}
}
@@ -278,9 +279,9 @@ register_size (struct gdbarch *gdbarch, int regnum)
gdb_assert (regnum >= 0 && regnum < (NUM_REGS + NUM_PSEUDO_REGS));
size = descr->sizeof_register[regnum];
- /* NB: The deprecated REGISTER_RAW_SIZE, if not provided, defaults
+ /* NB: The deprecated DEPRECATED_REGISTER_RAW_SIZE, if not provided, defaults
to the size of the register's type. */